Pairs warm/cool and related families to produce balanced diverging combinations that align with the Homage system.
Usage
albers_complement(
family = c("red", "lapis", "ochre", "teal", "green", "violet")
)Pairs warm/cool and related families to produce balanced diverging combinations that align with the Homage system.
albers_complement(
family = c("red", "lapis", "ochre", "teal", "green", "violet")
)