Skip to contents

This wrapper preserves the old name and forwards to use_albersdown().

Usage

use_albers_vignettes(path = ".", ...)

Arguments

path

Path to the package directory. Defaults to the current working directory to preserve the original wrapper behavior.

...

Additional arguments passed to use_albersdown().

Value

TRUE invisibly.

Examples

# \donttest{
if (interactive()) {
  use_albers_vignettes()
}
# }