Skip to contents

Quiet, legible gt style with subtle stripe from A300

Usage

gt_albers(
  x,
  family = "red",
  preset = c("homage", "study", "structural", "adobe", "midnight"),
  base_size = 14,
  width = 720,
  bg = NULL,
  fg = NULL
)

Arguments

x

A gt table

family

Palette family for subtle accents

preset

Visual preset (default "homage"). See albers_presets().

base_size

Base font size in pixels (default 14).

width

Table width in pixels (default 720). Use NULL for auto.

bg

Override background color (default derived from preset).

fg

Override text color (default derived from preset).

Value

A styled gt table object.

Examples

# \donttest{
if (requireNamespace("gt", quietly = TRUE)) {
  tbl <- gt::gt(head(mtcars))
  gt_albers(tbl)
}
mpg cyl disp hp drat wt qsec vs am gear carb
21.0 6 160 110 3.90 2.620 16.46 0 1 4 4
21.0 6 160 110 3.90 2.875 17.02 0 1 4 4
22.8 4 108 93 3.85 2.320 18.61 1 1 4 1
21.4 6 258 110 3.08 3.215 19.44 1 0 3 1
18.7 8 360 175 3.15 3.440 17.02 0 0 3 2
18.1 6 225 105 2.76 3.460 20.22 1 0 3 1
# }